// Untidy.NantTasks is Copyright (c) 2002 Simon Steele
// All rights reserved.
//
// See license.txt for the license conditions (BSD Style)

using System;
using NAnt.Core;
using NAnt.Core.Attributes;

namespace Untidy.NAntTasks
{
	/// <summary>Build locking task for Nant.</summary>
	[TaskName("lock")]
	public class BuildLocker : Task
	{
		string	_lockname;
		bool		_locked;

		#region Task Attributes
		/// <summary>Name of the lock to create.</summary>
		[TaskAttribute("name", Required=false)]
		public string LockName
		{
			get
			{
				return _lockname;
			}
			set
			{
				_lockname = value;
			}
		}
		#endregion

		~BuildLocker()
		{
			
		}

		public void BuildFinished(object sender, BuildEventArgs e) 
		{
			if(_locked)
			{
				Log(Level.Info, "Removing Build Lock File ({0})", _lockname);
				System.IO.File.Delete(_lockname);
			}
		}

		/// <summary>Create the .lock file</summary>
		protected override void ExecuteTask()
		{
			Project.BuildFinished += new BuildEventHandler(BuildFinished);
			Log(Level.Info, "Creating Build Lock File ({0})", _lockname);
			System.IO.StreamWriter writer = System.IO.File.CreateText(_lockname);
			writer.Write("1");
			writer.Close();
			_locked = true;
		}

		protected override void InitializeTask(System.Xml.XmlNode taskNode) 
		{
			if(_lockname == null || _lockname == "")
			{
				_lockname = Project.ProjectName + ".lock";
				_lockname = System.IO.Path.GetFullPath(_lockname);
			}
		}
	}
}
