// Untidy.NantTasks is Copyright (c) 2002 Simon Steele
// All rights reserved.
//
// See license.txt for the license conditions (BSD Style)

using System;
using System.Text.RegularExpressions;
using NAnt.Core.Attributes;

namespace Untidy.NAntTasks
{
	///   <note>External build number files must include a number of the form 
	///   "[0-9]+.[0-9]+.[0-9]+.[0-9]+" on the first line, including the quotes.</note>
	public class VersionNumberFile
	{
		string _fileName;
		Regex reCustomFileVersion = new Regex("(\")(?<a>[0-9]+)[\\.,](?<b>[0-9]+)[\\.,](?<c>[0-9]+)[\\.,](?<d>[0-9]+)(?<end>\")");

		public Regex Format
		{
			set { reCustomFileVersion = value; }
			get { return reCustomFileVersion; }
		}

		public VersionNumberFile()
		{
		}

		public VersionNumberFile(string fileName)
		{
			_fileName = fileName;
		}

		/// <summary>Reads the original version number from a file.</summary>
		public bool ReadVersion(VersionNumber version)
		{
			bool bSuccess = false;
			SimpleTextFile fIn = new SimpleTextFile(_fileName);
			fIn.Open();

			if(!fIn.EOF())
			{
				Match m = reCustomFileVersion.Match(fIn.ReadLine());
				if(m.Success)
				{
					bSuccess = true;
					version.SetFromMatch(m);
				}
				fIn.Close();
			}

			return bSuccess;
		}

		public void UpdateVersion(SimpleTextFile infile, SimpleTextFile outfile, VersionNumber vi)
		{
			string line;

			while(!infile.EOF())
			{
				line = vi.SwapVersionTags(infile.ReadLine(), reCustomFileVersion, false, "");
				outfile.WriteLine(line);
			}
		}

		public UpdateFunction GetUpdateFunction()
		{
			return new UpdateFunction(UpdateVersion);
		}
	}

	[TaskName("versionnumberfile")]
	public class VersionNumberFileTask : VersionNumberUpdater
	{
		VersionNumberFile vnf = new VersionNumberFile();

		protected override void ExecuteTask()
		{
			// As this is an updater, we check that the file in question exists.
			checkFile();

			// Now we write to the file using the update function from VersionInfoFile.
			updateFile( vnf.GetUpdateFunction() );
		}

	}

} // namespace Untidy.NantTasks